==> v2.6.5.1.tar.gz: gnosygnu_xowa/100_core/src_140_list/gplx/Hash_adp_.java <==
/*
XOWA: the XOWA Offline Wiki Application
Copyright (C) 2012 gnosygnu@gmail.com

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package gplx;
import gplx.core.primitives.*;
public class Hash_adp_ {
	public static Hash_adp new_() {return new Hash_adp_obj();}
	public static final Hash_adp Noop = new Hash_adp_noop();
}
class Hash_adp_obj extends gplx.lists.Hash_adp_base implements Hash_adp {}//_20110428
class Hash_adp_noop implements Hash_adp {
	public int Count() {return 0;}
	public boolean Has(Object key) {return false;}
	public Object Get_by(Object key) {return null;}
	public Object Get_by_or_fail(Object key)				{throw Err_.missing_key_(Object_.Xto_str_strict_or_null_mark(key));}
	public Object Get_by_or_new(Object key, NewAble proto) {throw Err_.new_("could not add to null hash");}
	public void Add(Object key, Object val) {}
	public void Add_as_key_and_val(Object val) {}
	public void Add_if_dupe_use_nth(Object key, Object val) {}
	public boolean Add_if_dupe_use_1st(Object key, Object val) {return false;}
	public void Del(Object key) {}
	public void Clear() {}
	public java.util.Iterator iterator() {return gplx.lists.Iterator_null._;}
}

==> v2.7.2.1.tar.gz: gnosygnu_xowa/100_core/src_140_list/gplx/Hash_adp_.java <==
/*
XOWA: the XOWA Offline Wiki Application
Copyright (C) 2012 gnosygnu@gmail.com

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package gplx;
import gplx.core.primitives.*;
public class Hash_adp_ {
	public static Hash_adp new_() {return new Hash_adp_obj();}
	public static final Hash_adp Noop = new Hash_adp_noop();
}
class Hash_adp_obj extends gplx.lists.Hash_adp_base implements Hash_adp {}//_20110428
class Hash_adp_noop implements Hash_adp {
	public int Count() {return 0;}
	public boolean Has(Object key) {return false;}
	public Object Get_by(Object key) {return null;}
	public Object Get_by_or_fail(Object key)				{throw Exc_.new_missing_key(Object_.Xto_str_strict_or_null_mark(key));}
	public Object Get_by_or_new(Object key, NewAble proto) {throw Exc_.new_("could not add to null hash");}
	public void Add(Object key, Object val) {}
	public void Add_as_key_and_val(Object val) {}
	public void Add_if_dupe_use_nth(Object key, Object val) {}
	public boolean Add_if_dupe_use_1st(Object key, Object val) {return false;}
	public void Del(Object key) {}
	public void Clear() {}
	public java.util.Iterator iterator() {return gplx.lists.Iterator_null._;}
}
